Explanations
============

In-depth explanations of how deltacamera works.

.. toctree::
   :maxdepth: 1

   reprojection
   distortion-validity
   distortion-rotation
   distortion-parameter-transforms
   distortion-valid-regions
   perspective-aware-cropping
   sympy-codegen
   pytorch-internals
